@@ -49,7 +49,7 @@ random.seed()
 
 
 #Erstellen der Mainklasse
-#vib=input("AN1/AUS0")
+
 
 class MainWindow(QtGui.QMainWindow):
     def __init__(self, parent=None):
@@ -59,8 +59,6 @@ class MainWindow(QtGui.QMainWindow):
         self.ui=loadUi("/opt/farty/furzkissen.ui")
         self.ui.show()
         self.ui.showFullScreen()
-        self.ui.viboff.setChecked(1)
-        self.ui.vibon.setCheckable(True)
         
  
         #Vibration
@@ -77,6 +75,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.wolke.hide()
         self.ui.wolke2.hide()
         self.ui.wolke3.hide()
+        self.ui.checkedButton.hide()
        
         #Zuordnung der Buttons mit Verweis auf deren Methoden
        
@@ -86,17 +85,35 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.idea.clicked.connect(self.ideafunc)
         self.ui.about.clicked.connect(self.aboutfunc)
         self.ui.craveo.clicked.connect(self.craveobrowser)
+        self.ui.checkButton.toggled.connect(self.checked)
+        self.ui.checkedButton.toggled.connect(self.unchecked)
+                
+    def checked(self):    
+        self.ui.checkButton.hide()
+        self.ui.checkedButton.show()
+        self.ui.checkedButton.setChecked(False)
+            
+    def unchecked(self):
+        self.ui.checkedButton.hide()
+        self.ui.checkButton.show()
+        self.ui.checkButton.setChecked(False)
+        
+            
 
         #Methoden
        
     def fartrandom(self):#Zufallsmechanismus für Abspielen der Furzsounds 10-81 
         
-        if self.ui.vibon.isChecked():
+        if self.ui.checkButton.isChecked():
+            print"Vibration"
+            pass
+            print "checked"
             for _ in range(2):
                 self.rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,
                                  self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
         else:
-            pass        
+            print"noVibration"
+            pass     
         fartnumber=random.randint(10,81)
         path="/opt/farty/Furzsounds/furz0"+str(fartnumber)+".wav"
         sound=pygame.mixer.Sound(path)
@@ -122,6 +139,7 @@ class MainWindow(QtGui.QMainWindow):
         
     def aboutfunc(self):
         QtGui.QMessageBox.aboutQt(self) 
+        
        
    
        
